@@ -19,6 +19,7 @@ no Moose;
 
 -1;
 
+__END__
 
 # ABSTRACT: Query field object
 
@@ -34,6 +35,19 @@ L<Moose>
 
 =head1 METHODS
 
+=head2 new
+
+ Salvation::MacroProcessor::Field -> new(
+ 	description => $description,
+	value => $value
+ )
+
+Constructor.
+
+Returns B<Salvation::MacroProcessor::Field> instance.
+
+All arguments documented at this section below.
+
 =head2 description
 
  $field -> description()
