@@ -102,12 +102,69 @@ __END__
 
 Salvation::MacroProcessor::Iterator - An iterator for reading query results
 
+=head1 DESCRIPTION
+
+=head2 What is it?
+
+B<Salvation::MacroProcessor::Iterator> is an iterator class. It should be wrapped around your custom iterator and supplied some C<postfilter>ing function which will execute L<Salvation::MacroProcessor::MethodDescription>C<::postfitler> routine.
+
+=head2 Example usage
+
+ my $it = Salvation::MacroProcessor::Iterator -> new(
+ 	postfilter => $CodeRef,
+	iterator => $it
+ );
+
 =head1 REQUIRES
 
 L<Moose> 
 
 =head1 METHODS
 
+=head2 new
+
+ Salvation::MacroProcessor::Iterator -> new(
+ 	postfilter => $CodeRef,
+	iterator => $it
+ )
+
+Constructor.
+
+Returns B<Salvation::MacroProcessor::Iterator> instance.
+
+Arguments:
+
+=over
+
+=item postfilter
+
+A CodeRef matching following signature:
+
+ ( Any $object )
+
+. C<$object> is an object representing a single row of data returned by the query.
+
+C<$CodeRef> function will be executed for each row to check if this row is suitable as a result for caller, or not.
+
+Boolean value should be returned, C<false> means "skip this object" and C<true> means "yes, this object is what we want".
+
+It is common to make C<$CodeRef> look like that:
+
+ sub
+ {
+ 	$spec -> __postfilter_each( shift )
+ }
+
+, where C<$spec> is a L<Salvation::MacroProcessor::Spec> instance.
+
+=item iterator
+
+An Object that does L<Salvation::MacroProcessor::Iterator::Compliance> role.
+
+B<Salvation::MacroProcessor::Iterator> will be wrapped around this object.
+
+=back
+
 =head2 first
 
  $object -> first()
